# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class NotificationControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_notification_request_using_post(self, **kwargs):  # noqa: E501
        """Create notification request (createNotificationRequest)  # noqa: E501

        Processes notification request. Mandatory request properties are `targets` (list of targets ids to send notification to), and either `templateId` (existing notification template id) or `template` (to send notification without saving the template). Optionally, you can set `sendingDelayInSec` inside the `additionalConfig` field to schedule the notification.  For each enabled delivery method in the notification template, there must be a target in the `targets` list that supports this delivery method: if you chose `WEB`, `EMAIL` or `SMS` - there must be at least one target in `targets` of `PLATFORM_USERS` type. For `SLACK` delivery method - you need to chose at least one `SLACK` notification target.  Notification request object with `PROCESSING` status will be returned immediately, and the notification sending itself is done asynchronously. After all notifications are sent, the `status` of the request becomes `SENT`. Use `getNotificationRequestById` to see the notification request processing status and some sending stats.   Here is an example of notification request to one target using saved template: ```json {   \"templateId\": {     \"entityType\": \"NOTIFICATION_TEMPLATE\",     \"id\": \"6dbc3670-e4dd-11ed-9401-dbcc5dff78be\"   },   \"targets\": [     \"320e3ed0-d785-11ed-a06c-21dd57dd88ca\"   ],   \"additionalConfig\": {     \"sendingDelayInSec\": 0   } } ```  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_notification_request_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotificationRequest body:
        :return: NotificationRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_notification_request_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_notification_request_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_notification_request_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Create notification request (createNotificationRequest)  # noqa: E501

        Processes notification request. Mandatory request properties are `targets` (list of targets ids to send notification to), and either `templateId` (existing notification template id) or `template` (to send notification without saving the template). Optionally, you can set `sendingDelayInSec` inside the `additionalConfig` field to schedule the notification.  For each enabled delivery method in the notification template, there must be a target in the `targets` list that supports this delivery method: if you chose `WEB`, `EMAIL` or `SMS` - there must be at least one target in `targets` of `PLATFORM_USERS` type. For `SLACK` delivery method - you need to chose at least one `SLACK` notification target.  Notification request object with `PROCESSING` status will be returned immediately, and the notification sending itself is done asynchronously. After all notifications are sent, the `status` of the request becomes `SENT`. Use `getNotificationRequestById` to see the notification request processing status and some sending stats.   Here is an example of notification request to one target using saved template: ```json {   \"templateId\": {     \"entityType\": \"NOTIFICATION_TEMPLATE\",     \"id\": \"6dbc3670-e4dd-11ed-9401-dbcc5dff78be\"   },   \"targets\": [     \"320e3ed0-d785-11ed-a06c-21dd57dd88ca\"   ],   \"additionalConfig\": {     \"sendingDelayInSec\": 0   } } ```  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_notification_request_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotificationRequest body:
        :return: NotificationRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_notification_request_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/request', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationRequest',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_notification_request_using_delete(self, id, **kwargs):  # noqa: E501
        """Delete notification request (deleteNotificationRequest)  # noqa: E501

        Deletes notification request by its id.  If the request has status `SENT` - all sent notifications for this request will be deleted. If it is `SCHEDULED`, the request will be cancelled.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_notification_request_using_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_notification_request_using_delete_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_notification_request_using_delete_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_notification_request_using_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete notification request (deleteNotificationRequest)  # noqa: E501

        Deletes notification request by its id.  If the request has status `SENT` - all sent notifications for this request will be deleted. If it is `SCHEDULED`, the request will be cancelled.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_notification_request_using_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_notification_request_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_notification_request_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/request/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_notification_using_delete(self, id, **kwargs):  # noqa: E501
        """Delete notification (deleteNotification)  # noqa: E501

        Deletes notification by its id.  Available for any authorized user.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_notification_using_delete(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_notification_using_delete_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_notification_using_delete_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_notification_using_delete_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete notification (deleteNotification)  # noqa: E501

        Deletes notification by its id.  Available for any authorized user.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_notification_using_delete_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_notification_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_notification_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_available_delivery_methods_using_get(self, **kwargs):  # noqa: E501
        """Get available delivery methods (getAvailableDeliveryMethods)  # noqa: E501

        Returns the list of delivery methods that are properly configured and are allowed to be used for sending notifications.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_delivery_methods_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_available_delivery_methods_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_available_delivery_methods_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_available_delivery_methods_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get available delivery methods (getAvailableDeliveryMethods)  # noqa: E501

        Returns the list of delivery methods that are properly configured and are allowed to be used for sending notifications.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_available_delivery_methods_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_available_delivery_methods_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/deliveryMethods', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[str]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_notification_request_by_id_using_get(self, id, **kwargs):  # noqa: E501
        """Get notification request by id (getNotificationRequestById)  # noqa: E501

        Fetches notification request info by request id.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_request_by_id_using_get(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: NotificationRequestInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_notification_request_by_id_using_get_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_notification_request_by_id_using_get_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_notification_request_by_id_using_get_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get notification request by id (getNotificationRequestById)  # noqa: E501

        Fetches notification request info by request id.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_request_by_id_using_get_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: NotificationRequestInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_notification_request_by_id_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_notification_request_by_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/request/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationRequestInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_notification_request_preview_using_post(self, **kwargs):  # noqa: E501
        """Get notification request preview (getNotificationRequestPreview)  # noqa: E501

        Returns preview for notification request.  `processedTemplates` shows how the notifications for each delivery method will look like for the first recipient of the corresponding notification target.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_request_preview_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotificationRequest body:
        :param int recipients_preview_size: Amount of the recipients to show in preview
        :return: NotificationRequestPreview
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_notification_request_preview_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_notification_request_preview_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_notification_request_preview_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Get notification request preview (getNotificationRequestPreview)  # noqa: E501

        Returns preview for notification request.  `processedTemplates` shows how the notifications for each delivery method will look like for the first recipient of the corresponding notification target.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_request_preview_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotificationRequest body:
        :param int recipients_preview_size: Amount of the recipients to show in preview
        :return: NotificationRequestPreview
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'recipients_preview_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_notification_request_preview_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'recipients_preview_size' in params:
            query_params.append(('recipientsPreviewSize', params['recipients_preview_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/request/preview{?recipientsPreviewSize}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationRequestPreview',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_notification_requests_using_get(self, page_size, page, **kwargs):  # noqa: E501
        """Get notification requests (getNotificationRequests)  # noqa: E501

        Returns the page of notification requests submitted by users of this tenant or sysadmins.  You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_requests_using_get(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: Case-insensitive 'substring' filed based on the used template name
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataNotificationRequestInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_notification_requests_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_notification_requests_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def get_notification_requests_using_get_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """Get notification requests (getNotificationRequests)  # noqa: E501

        Returns the page of notification requests submitted by users of this tenant or sysadmins.  You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_requests_using_get_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: Case-insensitive 'substring' filed based on the used template name
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataNotificationRequestInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'text_search', 'sort_property', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_notification_requests_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_notification_requests_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_notification_requests_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/requests{?page,pageSize,sortOrder,sortProperty,textSearch}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataNotificationRequestInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_notification_settings_using_get(self, **kwargs):  # noqa: E501
        """Get notification settings (getNotificationSettings)  # noqa: E501

        Retrieves notification settings for this tenant or sysadmin.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_settings_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_notification_settings_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_notification_settings_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_notification_settings_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get notification settings (getNotificationSettings)  # noqa: E501

        Retrieves notification settings for this tenant or sysadmin.  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notification_settings_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_notification_settings_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/settings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationSettings',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_notifications_using_get(self, page_size, page, **kwargs):  # noqa: E501
        """Get notifications (getNotifications)  # noqa: E501

        Returns the page of notifications for current user.  You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for any authorized user.   **WebSocket API**:  There are 2 types of subscriptions: one for unread notifications count, another for unread notifications themselves.  The URI for opening WS session for notifications: `/api/ws/plugins/notifications`.  Subscription command for unread notifications count: ``` {   \"unreadCountSubCmd\": {     \"cmdId\": 1234   } } ``` To subscribe for latest unread notifications: ``` {   \"unreadSubCmd\": {     \"cmdId\": 1234,     \"limit\": 10   } } ``` To unsubscribe from any subscription: ``` {   \"unsubCmd\": {     \"cmdId\": 1234   } } ``` To mark certain notifications as read, use following command: ``` {   \"markAsReadCmd\": {     \"cmdId\": 1234,     \"notifications\": [       \"6f860330-7fc2-11ed-b855-7dd3b7d2faa9\",       \"5b6dfee0-8d0d-11ed-b61f-35a57b03dade\"     ]   } }  ``` To mark all notifications as read: ``` {   \"markAllAsReadCmd\": {     \"cmdId\": 1234   } } ```   Update structure for unread **notifications count subscription**: ``` {   \"cmdId\": 1234,   \"totalUnreadCount\": 55 } ``` For **notifications subscription**: - full update of latest unread notifications: ``` {   \"cmdId\": 1234,   \"notifications\": [     {       \"id\": {         \"entityType\": \"NOTIFICATION\",         \"id\": \"6f860330-7fc2-11ed-b855-7dd3b7d2faa9\"       },       ...     }   ],   \"totalUnreadCount\": 1 } ``` - when new notification arrives or shown notification is updated: ``` {   \"cmdId\": 1234,   \"update\": {     \"id\": {       \"entityType\": \"NOTIFICATION\",       \"id\": \"6f860330-7fc2-11ed-b855-7dd3b7d2faa9\"     },     # updated notification info, text, subject etc.     ...   },   \"totalUnreadCount\": 2 } ``` - when unread notifications count changes: ``` {   \"cmdId\": 1234,   \"totalUnreadCount\": 5 } ```  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notifications_using_get(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: Case-insensitive 'substring' filter based on notification subject or text
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param bool unread_only: To search for unread notifications only
        :return: PageDataNotification
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_notifications_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_notifications_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def get_notifications_using_get_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """Get notifications (getNotifications)  # noqa: E501

        Returns the page of notifications for current user.  You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details.   Available for any authorized user.   **WebSocket API**:  There are 2 types of subscriptions: one for unread notifications count, another for unread notifications themselves.  The URI for opening WS session for notifications: `/api/ws/plugins/notifications`.  Subscription command for unread notifications count: ``` {   \"unreadCountSubCmd\": {     \"cmdId\": 1234   } } ``` To subscribe for latest unread notifications: ``` {   \"unreadSubCmd\": {     \"cmdId\": 1234,     \"limit\": 10   } } ``` To unsubscribe from any subscription: ``` {   \"unsubCmd\": {     \"cmdId\": 1234   } } ``` To mark certain notifications as read, use following command: ``` {   \"markAsReadCmd\": {     \"cmdId\": 1234,     \"notifications\": [       \"6f860330-7fc2-11ed-b855-7dd3b7d2faa9\",       \"5b6dfee0-8d0d-11ed-b61f-35a57b03dade\"     ]   } }  ``` To mark all notifications as read: ``` {   \"markAllAsReadCmd\": {     \"cmdId\": 1234   } } ```   Update structure for unread **notifications count subscription**: ``` {   \"cmdId\": 1234,   \"totalUnreadCount\": 55 } ``` For **notifications subscription**: - full update of latest unread notifications: ``` {   \"cmdId\": 1234,   \"notifications\": [     {       \"id\": {         \"entityType\": \"NOTIFICATION\",         \"id\": \"6f860330-7fc2-11ed-b855-7dd3b7d2faa9\"       },       ...     }   ],   \"totalUnreadCount\": 1 } ``` - when new notification arrives or shown notification is updated: ``` {   \"cmdId\": 1234,   \"update\": {     \"id\": {       \"entityType\": \"NOTIFICATION\",       \"id\": \"6f860330-7fc2-11ed-b855-7dd3b7d2faa9\"     },     # updated notification info, text, subject etc.     ...   },   \"totalUnreadCount\": 2 } ``` - when unread notifications count changes: ``` {   \"cmdId\": 1234,   \"totalUnreadCount\": 5 } ```  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_notifications_using_get_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: Case-insensitive 'substring' filter based on notification subject or text
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :param bool unread_only: To search for unread notifications only
        :return: PageDataNotification
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'text_search', 'sort_property', 'sort_order', 'unread_only']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_notifications_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_notifications_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_notifications_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501
        if 'unread_only' in params:
            query_params.append(('unreadOnly', params['unread_only']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notifications{?page,pageSize,sortOrder,sortProperty,textSearch,unreadOnly}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataNotification',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_notification_settings_using_get(self, **kwargs):  # noqa: E501
        """getUserNotificationSettings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_notification_settings_using_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserNotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_notification_settings_using_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_user_notification_settings_using_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_user_notification_settings_using_get_with_http_info(self, **kwargs):  # noqa: E501
        """getUserNotificationSettings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_notification_settings_using_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserNotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_notification_settings_using_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/settings/user', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNotificationSettings',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def mark_all_notifications_as_read_using_put(self, **kwargs):  # noqa: E501
        """Mark all notifications as read (markAllNotificationsAsRead)  # noqa: E501

        Marks all unread notifications as read.  Available for any authorized user.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mark_all_notifications_as_read_using_put(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.mark_all_notifications_as_read_using_put_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.mark_all_notifications_as_read_using_put_with_http_info(**kwargs)  # noqa: E501
            return data

    def mark_all_notifications_as_read_using_put_with_http_info(self, **kwargs):  # noqa: E501
        """Mark all notifications as read (markAllNotificationsAsRead)  # noqa: E501

        Marks all unread notifications as read.  Available for any authorized user.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mark_all_notifications_as_read_using_put_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mark_all_notifications_as_read_using_put" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notifications/read', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def mark_notification_as_read_using_put(self, id, **kwargs):  # noqa: E501
        """Mark notification as read (markNotificationAsRead)  # noqa: E501

        Marks notification as read by its id.  Available for any authorized user.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mark_notification_as_read_using_put(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.mark_notification_as_read_using_put_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.mark_notification_as_read_using_put_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def mark_notification_as_read_using_put_with_http_info(self, id, **kwargs):  # noqa: E501
        """Mark notification as read (markNotificationAsRead)  # noqa: E501

        Marks notification as read by its id.  Available for any authorized user.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.mark_notification_as_read_using_put_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: id (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method mark_notification_as_read_using_put" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `mark_notification_as_read_using_put`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/{id}/read', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_notification_settings_using_post(self, **kwargs):  # noqa: E501
        """Save notification settings (saveNotificationSettings)  # noqa: E501

        Saves notification settings for this tenant or sysadmin. `deliveryMethodsConfigs` of the settings must be specified.  Here is an example of the notification settings with Slack configuration: ```json {   \"deliveryMethodsConfigs\": {     \"SLACK\": {       \"method\": \"SLACK\",       \"botToken\": \"xoxb-....\"     }   } } ```  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_notification_settings_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotificationSettings body:
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_notification_settings_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.save_notification_settings_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def save_notification_settings_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Save notification settings (saveNotificationSettings)  # noqa: E501

        Saves notification settings for this tenant or sysadmin. `deliveryMethodsConfigs` of the settings must be specified.  Here is an example of the notification settings with Slack configuration: ```json {   \"deliveryMethodsConfigs\": {     \"SLACK\": {       \"method\": \"SLACK\",       \"botToken\": \"xoxb-....\"     }   } } ```  Available for users with 'SYS_ADMIN' or 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_notification_settings_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NotificationSettings body:
        :return: NotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_notification_settings_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/settings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NotificationSettings',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_user_notification_settings_using_post(self, **kwargs):  # noqa: E501
        """saveUserNotificationSettings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_user_notification_settings_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserNotificationSettings body:
        :return: UserNotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_user_notification_settings_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.save_user_notification_settings_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def save_user_notification_settings_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """saveUserNotificationSettings  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_user_notification_settings_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserNotificationSettings body:
        :return: UserNotificationSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_user_notification_settings_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/notification/settings/user', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNotificationSettings',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import logging
from random import choice
from string import hexdigits
from time import sleep
from typing import Optional

from tb_rest_client.models.models_pe import EntityVersion, SingleEntityVersionCreateRequest, \
    SingleEntityVersionLoadRequest, VersionCreateConfig, VersionLoadConfig, Device, EntityId
from tb_rest_client.rest import ApiException
from tb_rest_client import RestClientPE

logging.basicConfig(level=logging.DEBUG,
                    format='%(asctime)s - %(levelname)s - %(module)s - %(lineno)d - %(message)s',
                    datefmt='%Y-%m-%d %H:%M:%S')

try:
    from deepdiff import DeepDiff
    from pprint import pformat
except ImportError:
    logging.error("Please install DeepDiff package using the following command first: \n pip3 install deepdiff")

# ThingsBoard REST API URL
url = "http://localhost:8080"

# Default Tenant Administrator credentials
username = "tenant@thingsboard.org"
password = "tenant"

test_basic_device_name = "Test Device A1"

test_attribute_key = "test_attribute"


def check_versions_for_entity(entity_id: EntityId):
    return rest_client.list_entity_versions(entity_id.entity_type, entity_id.id, default_branch['name'], 10, 0)['data']


def get_new_device_name(current_device_name: str):
    if "Extra" in current_device_name:
        new_device_name = current_device_name[:-5]
    else:
        new_device_name = current_device_name + "Extra"
    return new_device_name


def get_latest_test_attribute_value(entity_id: EntityId) -> Optional[int]:
    attribute_keys = rest_client.get_attributes_by_scope(entity_id, "SERVER_SCOPE", test_attribute_key)
    if attribute_keys:
        latest_attribute = attribute_keys[0]["value"]
        logging.info("Latest value: %r", latest_attribute)
        return latest_attribute
    else:
        return None


def update_device(device: Device, rest_client: RestClientPE) -> tuple[Device, int]:
    new_device_name = get_new_device_name(device.name)
    device.name = new_device_name
    latest_test_attribute_value = get_latest_test_attribute_value(device.id)
    if latest_test_attribute_value is not None:
        new_attribute_value = latest_test_attribute_value + 1
        result = rest_client.save_device_attributes(device.id, "SERVER_SCOPE",
                                                    {test_attribute_key: new_attribute_value})
    else:
        new_attribute_value = 0
        result = rest_client.save_device_attributes(device.id, "SERVER_SCOPE", {test_attribute_key: 0})

    logging.info(result)
    logging.info("After save")
    get_latest_test_attribute_value(device.id)

    return rest_client.save_device(device), new_attribute_value


if __name__ == '__main__':
    with RestClientPE(base_url=url) as rest_client:
        try:
            # Auth with credentials
            rest_client.login(username=username, password=password)

            # Get device
            tenant_devices = rest_client.get_tenant_devices(10, 0)
            test_device = next((device for device in tenant_devices.data if
                                device.name in (test_basic_device_name, test_basic_device_name + "Extra")))

            logging.info("Test device name is: %r", test_device.name)

            # VCS functionality testing
            # Get branches
            branches = rest_client.list_branches()
            logging.info("Branches: %r", branches)

            # Get default branch
            default_branch = next((branch for branch in branches if branch["default"]))
            logging.info("Default branch is: %r", default_branch)

            # Get versions for first branch
            try:
                versions_page_data = rest_client.list_versions(default_branch["name"], 10, 0)
                versions = versions_page_data['data']
                logging.info("Found versions: %r", versions)
            except ApiException as e:
                versions = []
            latest_version = {}

            if versions:
                create_new_versions_count = 2
            else:
                create_new_versions_count = 3

            # Create new versions for tests
            for _ in range(create_new_versions_count):
                updated_device, previous_version_test_attribute = update_device(test_device, rest_client)

                logging.info("Updated device name: %r", updated_device.name)

                # Create version create request for device
                device_version_create_request_config = VersionCreateConfig(True, True, True, True, True)
                vcr = SingleEntityVersionCreateRequest(default_branch['name'], device_version_create_request_config,
                                                       test_device.id, "SINGLE_ENTITY",
                                                       "".join(choice(hexdigits) for _ in range(5)))

                version_request_id = rest_client.save_entities_version(vcr)
                logging.info("Version request id: %r", version_request_id)

                # Get the result for request_status
                request_status = rest_client.get_version_create_request_status(version_request_id)
                while not isinstance(request_status, EntityVersion) and not request_status.done:
                    request_status = rest_client.get_version_create_request_status(version_request_id)
                    sleep(1)

                logging.info("Version creation result: %r", request_status)

                previous_version = latest_version
                latest_version = check_versions_for_entity(test_device.id)[0]

            # latest version information
            logging.info(f"Latest version information:\n\
                           Name: {latest_version['name']}\n\
                           Timestamp: {latest_version['timestamp']}\n\
                           Version id: {latest_version['id']}\n\
                           Author: {latest_version['author']}")

            # Getting devices in the latest version
            devices_at_version = rest_client.list_entities_at_version("DEVICE", latest_version['id'])
            logging.info("Device ids at latest version: %r",
                         [device_in_version['externalId']['id'] for device_in_version in devices_at_version])

            assert previous_version['name'] != latest_version['name']
            assert previous_version['timestamp'] != latest_version['timestamp']
            assert previous_version['id'] != latest_version['id']

            # Revert previous version

            # Select previous version
            target_version = {k: previous_version[k] for k in previous_version}
            logging.info("Restoring to version with name: %r", target_version['name'])

            # Create load version request for previous version
            device_version_load_request_config = VersionLoadConfig(True, True, True, True, True, True)
            previous_version_load_request = SingleEntityVersionLoadRequest(device_version_load_request_config,
                                                                           test_device.id, test_device.id,
                                                                           "SINGLE_ENTITY", previous_version['id'])

            load_request_id = rest_client.load_entities_version(previous_version_load_request)

            load_request_status = rest_client.get_version_load_request_status(load_request_id)
            # Wait for restoring and check status
            while not isinstance(load_request_status, EntityVersion) and not load_request_status.done:
                load_request_status = rest_client.get_version_load_request_status(load_request_id)
                sleep(1)

            logging.info("Version load result: %r", load_request_status)

            previous_version = latest_version
            latest_version = check_versions_for_entity(test_device.id)[0]
            latest_version_test_attribute = get_latest_test_attribute_value(test_device.id)

            assert target_version['name'] != latest_version['name']
            assert target_version['timestamp'] != latest_version['timestamp']
            assert target_version['id'] != latest_version['id']
            assert previous_version_test_attribute != latest_version_test_attribute

            tenant_devices = rest_client.get_tenant_devices(10, 0)
            test_device = next((device for device in tenant_devices.data if
                                device.name in (test_basic_device_name, test_basic_device_name + "Extra")))

            logging.info("Device version with name %r was restored, current device name is: %r", target_version['name'],
                         test_device.name)
            logging.info(
                f"Current test attribute value is {latest_version_test_attribute}, previous version attribute value was {previous_version_test_attribute}")

            # Compare current device version to the latest version

            device_versions_dict = rest_client.compare_entity_data_to_version(test_device.id, latest_version['id'])
            logging.info("Difference between device entities are: \n %s", pformat(
                DeepDiff(device_versions_dict['currentVersion'], device_versions_dict['otherVersion'])[
                    "values_changed"], indent=2))

            # Get device infos for current and latest versions

            entity_data_info = rest_client.get_entity_data_info(target_version['id'], test_device.id)
            logging.info("Current version entity info data: %r", entity_data_info)

            entity_data_info = rest_client.get_entity_data_info(latest_version['id'], test_device.id)
            logging.info("Latest version entity info data: %r", entity_data_info)

        except ApiException as e:
            logging.exception(e)



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.3.3PAAS-RC1
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class ServerSecurityConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.
from tb_rest_client.api_client import ApiClient
    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bootstrap_server_is': 'bool',
        'host': 'str',
        'port': 'int',
        'security_host': 'str',
        'security_port': 'int',
        'server_id': 'int',
        'client_hold_off_time': 'int',
        'server_public_key': 'str',
        'bootstrap_server_account_timeout': 'int'
    }

    attribute_map = {
        'bootstrap_server_is': 'bootstrapServerIs',
        'host': 'host',
        'port': 'port',
        'security_host': 'securityHost',
        'security_port': 'securityPort',
        'server_id': 'serverId',
        'client_hold_off_time': 'clientHoldOffTime',
        'server_public_key': 'serverPublicKey',
        'bootstrap_server_account_timeout': 'bootstrapServerAccountTimeout'
    }

    def __init__(self, bootstrap_server_is=None, host=None, port=None, security_host=None, security_port=None, server_id=None, client_hold_off_time=None, server_public_key=None, bootstrap_server_account_timeout=None):  # noqa: E501
        """ServerSecurityConfig - a model defined in Swagger"""  # noqa: E501
        self._bootstrap_server_is = None
        self._host = None
        self._port = None
        self._security_host = None
        self._security_port = None
        self._server_id = None
        self._client_hold_off_time = None
        self._server_public_key = None
        self._bootstrap_server_account_timeout = None
        self.discriminator = None
        if bootstrap_server_is is not None:
            self.bootstrap_server_is = bootstrap_server_is
        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if security_host is not None:
            self.security_host = security_host
        if security_port is not None:
            self.security_port = security_port
        if server_id is not None:
            self.server_id = server_id
        if client_hold_off_time is not None:
            self.client_hold_off_time = client_hold_off_time
        if server_public_key is not None:
            self.server_public_key = server_public_key
        if bootstrap_server_account_timeout is not None:
            self.bootstrap_server_account_timeout = bootstrap_server_account_timeout

    @property
    def bootstrap_server_is(self):
        """Gets the bootstrap_server_is of this ServerSecurityConfig.  # noqa: E501

        Is Bootstrap Server  # noqa: E501

        :return: The bootstrap_server_is of this ServerSecurityConfig.  # noqa: E501
        :rtype: bool
        """
        return self._bootstrap_server_is

    @bootstrap_server_is.setter
    def bootstrap_server_is(self, bootstrap_server_is):
        """Sets the bootstrap_server_is of this ServerSecurityConfig.

        Is Bootstrap Server  # noqa: E501

        :param bootstrap_server_is: The bootstrap_server_is of this ServerSecurityConfig.  # noqa: E501
        :type: bool
        """

        self._bootstrap_server_is = bootstrap_server_is

    @property
    def host(self):
        """Gets the host of this ServerSecurityConfig.  # noqa: E501

        Host for 'No Security' mode  # noqa: E501

        :return: The host of this ServerSecurityConfig.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this ServerSecurityConfig.

        Host for 'No Security' mode  # noqa: E501

        :param host: The host of this ServerSecurityConfig.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def port(self):
        """Gets the port of this ServerSecurityConfig.  # noqa: E501

        Port for 'No Security' mode  # noqa: E501

        :return: The port of this ServerSecurityConfig.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this ServerSecurityConfig.

        Port for 'No Security' mode  # noqa: E501

        :param port: The port of this ServerSecurityConfig.  # noqa: E501
        :type: int
        """

        self._port = port

    @property
    def security_host(self):
        """Gets the security_host of this ServerSecurityConfig.  # noqa: E501

        Host for 'Security' mode (DTLS)  # noqa: E501

        :return: The security_host of this ServerSecurityConfig.  # noqa: E501
        :rtype: str
        """
        return self._security_host

    @security_host.setter
    def security_host(self, security_host):
        """Sets the security_host of this ServerSecurityConfig.

        Host for 'Security' mode (DTLS)  # noqa: E501

        :param security_host: The security_host of this ServerSecurityConfig.  # noqa: E501
        :type: str
        """

        self._security_host = security_host

    @property
    def security_port(self):
        """Gets the security_port of this ServerSecurityConfig.  # noqa: E501

        Port for 'Security' mode (DTLS)  # noqa: E501

        :return: The security_port of this ServerSecurityConfig.  # noqa: E501
        :rtype: int
        """
        return self._security_port

    @security_port.setter
    def security_port(self, security_port):
        """Sets the security_port of this ServerSecurityConfig.

        Port for 'Security' mode (DTLS)  # noqa: E501

        :param security_port: The security_port of this ServerSecurityConfig.  # noqa: E501
        :type: int
        """

        self._security_port = security_port

    @property
    def server_id(self):
        """Gets the server_id of this ServerSecurityConfig.  # noqa: E501

        Server short Id  # noqa: E501

        :return: The server_id of this ServerSecurityConfig.  # noqa: E501
        :rtype: int
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this ServerSecurityConfig.

        Server short Id  # noqa: E501

        :param server_id: The server_id of this ServerSecurityConfig.  # noqa: E501
        :type: int
        """

        self._server_id = server_id

    @property
    def client_hold_off_time(self):
        """Gets the client_hold_off_time of this ServerSecurityConfig.  # noqa: E501

        Client Hold Off Time  # noqa: E501

        :return: The client_hold_off_time of this ServerSecurityConfig.  # noqa: E501
        :rtype: int
        """
        return self._client_hold_off_time

    @client_hold_off_time.setter
    def client_hold_off_time(self, client_hold_off_time):
        """Sets the client_hold_off_time of this ServerSecurityConfig.

        Client Hold Off Time  # noqa: E501

        :param client_hold_off_time: The client_hold_off_time of this ServerSecurityConfig.  # noqa: E501
        :type: int
        """

        self._client_hold_off_time = client_hold_off_time

    @property
    def server_public_key(self):
        """Gets the server_public_key of this ServerSecurityConfig.  # noqa: E501

        Server Public Key (base64 encoded)  # noqa: E501

        :return: The server_public_key of this ServerSecurityConfig.  # noqa: E501
        :rtype: str
        """
        return self._server_public_key

    @server_public_key.setter
    def server_public_key(self, server_public_key):
        """Sets the server_public_key of this ServerSecurityConfig.

        Server Public Key (base64 encoded)  # noqa: E501

        :param server_public_key: The server_public_key of this ServerSecurityConfig.  # noqa: E501
        :type: str
        """

        self._server_public_key = server_public_key

    @property
    def bootstrap_server_account_timeout(self):
        """Gets the bootstrap_server_account_timeout of this ServerSecurityConfig.  # noqa: E501

        Bootstrap Server Account Timeout  # noqa: E501

        :return: The bootstrap_server_account_timeout of this ServerSecurityConfig.  # noqa: E501
        :rtype: int
        """
        return self._bootstrap_server_account_timeout

    @bootstrap_server_account_timeout.setter
    def bootstrap_server_account_timeout(self, bootstrap_server_account_timeout):
        """Sets the bootstrap_server_account_timeout of this ServerSecurityConfig.

        Bootstrap Server Account Timeout  # noqa: E501

        :param bootstrap_server_account_timeout: The bootstrap_server_account_timeout of this ServerSecurityConfig.  # noqa: E501
        :type: int
        """

        self._bootstrap_server_account_timeout = bootstrap_server_account_timeout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServerSecurityConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerSecurityConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class ThingsboardErrorResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'int',
        'message': 'str',
        'error_code': 'object',
        'timestamp': 'datetime'
    }

    attribute_map = {
        'status': 'status',
        'message': 'message',
        'error_code': 'errorCode',
        'timestamp': 'timestamp'
    }

    def __init__(self, status=None, message=None, error_code=None, timestamp=None):  # noqa: E501
        """ThingsboardErrorResponse - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._message = None
        self._error_code = None
        self._timestamp = None
        self.discriminator = None
        if status is not None:
            self.status = status
        if message is not None:
            self.message = message
        if error_code is not None:
            self.error_code = error_code
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def status(self):
        """Gets the status of this ThingsboardErrorResponse.  # noqa: E501

        HTTP Response Status Code  # noqa: E501

        :return: The status of this ThingsboardErrorResponse.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ThingsboardErrorResponse.

        HTTP Response Status Code  # noqa: E501

        :param status: The status of this ThingsboardErrorResponse.  # noqa: E501
        :type: int
        """

        self._status = status

    @property
    def message(self):
        """Gets the message of this ThingsboardErrorResponse.  # noqa: E501

        Error message  # noqa: E501

        :return: The message of this ThingsboardErrorResponse.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ThingsboardErrorResponse.

        Error message  # noqa: E501

        :param message: The message of this ThingsboardErrorResponse.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def error_code(self):
        """Gets the error_code of this ThingsboardErrorResponse.  # noqa: E501

        Platform error code: * `2` - General error (HTTP: 500 - Internal Server Error)  * `10` - Authentication failed (HTTP: 401 - Unauthorized)  * `11` - JWT token expired (HTTP: 401 - Unauthorized)  * `15` - Credentials expired (HTTP: 401 - Unauthorized)  * `20` - Permission denied (HTTP: 403 - Forbidden)  * `30` - Invalid arguments (HTTP: 400 - Bad Request)  * `31` - Bad request params (HTTP: 400 - Bad Request)  * `32` - Item not found (HTTP: 404 - Not Found)  * `33` - Too many requests (HTTP: 429 - Too Many Requests)  * `34` - Too many updates (Too many updates over Websocket session)  * `40` - Subscription violation (HTTP: 403 - Forbidden)  # noqa: E501

        :return: The error_code of this ThingsboardErrorResponse.  # noqa: E501
        :rtype: object
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this ThingsboardErrorResponse.

        Platform error code: * `2` - General error (HTTP: 500 - Internal Server Error)  * `10` - Authentication failed (HTTP: 401 - Unauthorized)  * `11` - JWT token expired (HTTP: 401 - Unauthorized)  * `15` - Credentials expired (HTTP: 401 - Unauthorized)  * `20` - Permission denied (HTTP: 403 - Forbidden)  * `30` - Invalid arguments (HTTP: 400 - Bad Request)  * `31` - Bad request params (HTTP: 400 - Bad Request)  * `32` - Item not found (HTTP: 404 - Not Found)  * `33` - Too many requests (HTTP: 429 - Too Many Requests)  * `34` - Too many updates (Too many updates over Websocket session)  * `40` - Subscription violation (HTTP: 403 - Forbidden)  # noqa: E501

        :param error_code: The error_code of this ThingsboardErrorResponse.  # noqa: E501
        :type: object
        """

        self._error_code = error_code

    @property
    def timestamp(self):
        """Gets the timestamp of this ThingsboardErrorResponse.  # noqa: E501

        Timestamp  # noqa: E501

        :return: The timestamp of this ThingsboardErrorResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ThingsboardErrorResponse.

        Timestamp  # noqa: E501

        :param timestamp: The timestamp of this ThingsboardErrorResponse.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ThingsboardErrorResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ThingsboardErrorResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class ProcessingStrategy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'failure_percentage': 'float',
        'max_pause_between_retries': 'int',
        'pause_between_retries': 'int',
        'retries': 'int',
        'type': 'str'
    }

    attribute_map = {
        'failure_percentage': 'failurePercentage',
        'max_pause_between_retries': 'maxPauseBetweenRetries',
        'pause_between_retries': 'pauseBetweenRetries',
        'retries': 'retries',
        'type': 'type'
    }

    def __init__(self, failure_percentage=None, max_pause_between_retries=None, pause_between_retries=None, retries=None, type=None):  # noqa: E501
        """ProcessingStrategy - a model defined in Swagger"""  # noqa: E501
        self._failure_percentage = None
        self._max_pause_between_retries = None
        self._pause_between_retries = None
        self._retries = None
        self._type = None
        self.discriminator = None
        if failure_percentage is not None:
            self.failure_percentage = failure_percentage
        if max_pause_between_retries is not None:
            self.max_pause_between_retries = max_pause_between_retries
        if pause_between_retries is not None:
            self.pause_between_retries = pause_between_retries
        if retries is not None:
            self.retries = retries
        if type is not None:
            self.type = type

    @property
    def failure_percentage(self):
        """Gets the failure_percentage of this ProcessingStrategy.  # noqa: E501


        :return: The failure_percentage of this ProcessingStrategy.  # noqa: E501
        :rtype: float
        """
        return self._failure_percentage

    @failure_percentage.setter
    def failure_percentage(self, failure_percentage):
        """Sets the failure_percentage of this ProcessingStrategy.


        :param failure_percentage: The failure_percentage of this ProcessingStrategy.  # noqa: E501
        :type: float
        """

        self._failure_percentage = failure_percentage

    @property
    def max_pause_between_retries(self):
        """Gets the max_pause_between_retries of this ProcessingStrategy.  # noqa: E501


        :return: The max_pause_between_retries of this ProcessingStrategy.  # noqa: E501
        :rtype: int
        """
        return self._max_pause_between_retries

    @max_pause_between_retries.setter
    def max_pause_between_retries(self, max_pause_between_retries):
        """Sets the max_pause_between_retries of this ProcessingStrategy.


        :param max_pause_between_retries: The max_pause_between_retries of this ProcessingStrategy.  # noqa: E501
        :type: int
        """

        self._max_pause_between_retries = max_pause_between_retries

    @property
    def pause_between_retries(self):
        """Gets the pause_between_retries of this ProcessingStrategy.  # noqa: E501


        :return: The pause_between_retries of this ProcessingStrategy.  # noqa: E501
        :rtype: int
        """
        return self._pause_between_retries

    @pause_between_retries.setter
    def pause_between_retries(self, pause_between_retries):
        """Sets the pause_between_retries of this ProcessingStrategy.


        :param pause_between_retries: The pause_between_retries of this ProcessingStrategy.  # noqa: E501
        :type: int
        """

        self._pause_between_retries = pause_between_retries

    @property
    def retries(self):
        """Gets the retries of this ProcessingStrategy.  # noqa: E501


        :return: The retries of this ProcessingStrategy.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this ProcessingStrategy.


        :param retries: The retries of this ProcessingStrategy.  # noqa: E501
        :type: int
        """

        self._retries = retries

    @property
    def type(self):
        """Gets the type of this ProcessingStrategy.  # noqa: E501


        :return: The type of this ProcessingStrategy.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ProcessingStrategy.


        :param type: The type of this ProcessingStrategy.  # noqa: E501
        :type: str
        """
        allowed_values = ["RETRY_ALL", "RETRY_FAILED", "RETRY_FAILED_AND_TIMED_OUT", "RETRY_TIMED_OUT", "SKIP_ALL_FAILURES", "SKIP_ALL_FAILURES_AND_TIMED_OUT"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProcessingStrategy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessingStrategy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class TbResourceInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'descriptor': 'JsonNode',
        'link': 'str',
        'name': 'str',
        'public': 'bool',
        'public_link': 'str',
        'public_resource_key': 'str',
        'id': 'TbResourceId',
        'created_time': 'int',
        'tenant_id': 'TenantId',
        'title': 'str',
        'resource_type': 'str',
        'resource_key': 'str',
        'etag': 'str',
        'file_name': 'str'
    }

    attribute_map = {
        'descriptor': 'descriptor',
        'link': 'link',
        'name': 'name',
        'public': 'public',
        'public_link': 'publicLink',
        'public_resource_key': 'publicResourceKey',
        'id': 'id',
        'created_time': 'createdTime',
        'tenant_id': 'tenantId',
        'title': 'title',
        'resource_type': 'resourceType',
        'resource_key': 'resourceKey',
        'etag': 'etag',
        'file_name': 'fileName'
    }

    def __init__(self, descriptor=None, link=None, name=None, public=None, public_link=None, public_resource_key=None, id=None, created_time=None, tenant_id=None, title=None, resource_type=None, resource_key=None, etag=None, file_name=None):  # noqa: E501
        """TbResourceInfo - a model defined in Swagger"""  # noqa: E501
        self._descriptor = None
        self._link = None
        self._name = None
        self._public = None
        self._public_link = None
        self._public_resource_key = None
        self._id = None
        self._created_time = None
        self._tenant_id = None
        self._title = None
        self._resource_type = None
        self._resource_key = None
        self._etag = None
        self._file_name = None
        self.discriminator = None
        if descriptor is not None:
            self.descriptor = descriptor
        if link is not None:
            self.link = link
        if name is not None:
            self.name = name
        if public is not None:
            self.public = public
        if public_link is not None:
            self.public_link = public_link
        if public_resource_key is not None:
            self.public_resource_key = public_resource_key
        if id is not None:
            self.id = id
        if created_time is not None:
            self.created_time = created_time
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if title is not None:
            self.title = title
        if resource_type is not None:
            self.resource_type = resource_type
        if resource_key is not None:
            self.resource_key = resource_key
        if etag is not None:
            self.etag = etag
        if file_name is not None:
            self.file_name = file_name

    @property
    def descriptor(self):
        """Gets the descriptor of this TbResourceInfo.  # noqa: E501


        :return: The descriptor of this TbResourceInfo.  # noqa: E501
        :rtype: JsonNode
        """
        return self._descriptor

    @descriptor.setter
    def descriptor(self, descriptor):
        """Sets the descriptor of this TbResourceInfo.


        :param descriptor: The descriptor of this TbResourceInfo.  # noqa: E501
        :type: JsonNode
        """

        self._descriptor = descriptor

    @property
    def link(self):
        """Gets the link of this TbResourceInfo.  # noqa: E501


        :return: The link of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this TbResourceInfo.


        :param link: The link of this TbResourceInfo.  # noqa: E501
        :type: str
        """

        self._link = link

    @property
    def name(self):
        """Gets the name of this TbResourceInfo.  # noqa: E501


        :return: The name of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TbResourceInfo.


        :param name: The name of this TbResourceInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def public(self):
        """Gets the public of this TbResourceInfo.  # noqa: E501


        :return: The public of this TbResourceInfo.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this TbResourceInfo.


        :param public: The public of this TbResourceInfo.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def public_link(self):
        """Gets the public_link of this TbResourceInfo.  # noqa: E501


        :return: The public_link of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._public_link

    @public_link.setter
    def public_link(self, public_link):
        """Sets the public_link of this TbResourceInfo.


        :param public_link: The public_link of this TbResourceInfo.  # noqa: E501
        :type: str
        """

        self._public_link = public_link

    @property
    def public_resource_key(self):
        """Gets the public_resource_key of this TbResourceInfo.  # noqa: E501


        :return: The public_resource_key of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._public_resource_key

    @public_resource_key.setter
    def public_resource_key(self, public_resource_key):
        """Sets the public_resource_key of this TbResourceInfo.


        :param public_resource_key: The public_resource_key of this TbResourceInfo.  # noqa: E501
        :type: str
        """

        self._public_resource_key = public_resource_key

    @property
    def id(self):
        """Gets the id of this TbResourceInfo.  # noqa: E501


        :return: The id of this TbResourceInfo.  # noqa: E501
        :rtype: TbResourceId
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TbResourceInfo.


        :param id: The id of this TbResourceInfo.  # noqa: E501
        :type: TbResourceId
        """

        self._id = id

    @property
    def created_time(self):
        """Gets the created_time of this TbResourceInfo.  # noqa: E501

        Timestamp of the resource creation, in milliseconds  # noqa: E501

        :return: The created_time of this TbResourceInfo.  # noqa: E501
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this TbResourceInfo.

        Timestamp of the resource creation, in milliseconds  # noqa: E501

        :param created_time: The created_time of this TbResourceInfo.  # noqa: E501
        :type: int
        """

        self._created_time = created_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this TbResourceInfo.  # noqa: E501


        :return: The tenant_id of this TbResourceInfo.  # noqa: E501
        :rtype: TenantId
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this TbResourceInfo.


        :param tenant_id: The tenant_id of this TbResourceInfo.  # noqa: E501
        :type: TenantId
        """

        self._tenant_id = tenant_id

    @property
    def title(self):
        """Gets the title of this TbResourceInfo.  # noqa: E501

        Resource title.  # noqa: E501

        :return: The title of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this TbResourceInfo.

        Resource title.  # noqa: E501

        :param title: The title of this TbResourceInfo.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def resource_type(self):
        """Gets the resource_type of this TbResourceInfo.  # noqa: E501

        Resource type.  # noqa: E501

        :return: The resource_type of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this TbResourceInfo.

        Resource type.  # noqa: E501

        :param resource_type: The resource_type of this TbResourceInfo.  # noqa: E501
        :type: str
        """
        allowed_values = ["IMAGE", "JKS", "JS_MODULE", "LWM2M_MODEL", "PKCS_12"]  # noqa: E501
        if resource_type not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def resource_key(self):
        """Gets the resource_key of this TbResourceInfo.  # noqa: E501

        Resource key.  # noqa: E501

        :return: The resource_key of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._resource_key

    @resource_key.setter
    def resource_key(self, resource_key):
        """Sets the resource_key of this TbResourceInfo.

        Resource key.  # noqa: E501

        :param resource_key: The resource_key of this TbResourceInfo.  # noqa: E501
        :type: str
        """

        self._resource_key = resource_key

    @property
    def etag(self):
        """Gets the etag of this TbResourceInfo.  # noqa: E501

        Resource etag.  # noqa: E501

        :return: The etag of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._etag

    @etag.setter
    def etag(self, etag):
        """Sets the etag of this TbResourceInfo.

        Resource etag.  # noqa: E501

        :param etag: The etag of this TbResourceInfo.  # noqa: E501
        :type: str
        """

        self._etag = etag

    @property
    def file_name(self):
        """Gets the file_name of this TbResourceInfo.  # noqa: E501

        Resource file name.  # noqa: E501

        :return: The file_name of this TbResourceInfo.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this TbResourceInfo.

        Resource file name.  # noqa: E501

        :param file_name: The file_name of this TbResourceInfo.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TbResourceInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TbResourceInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard open-source IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from tb_rest_client.api_client import ApiClient


class OtaPackageControllerApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def delete_ota_package_using_delete(self, ota_package_id, **kwargs):  # noqa: E501
        """Delete OTA Package (deleteOtaPackage)  # noqa: E501

        Deletes the OTA Package. Referencing non-existing OTA Package Id will cause an error. Can't delete the OTA Package if it is referenced by existing devices or device profile.  Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ota_package_using_delete(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_ota_package_using_delete_with_http_info(ota_package_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_ota_package_using_delete_with_http_info(ota_package_id, **kwargs)  # noqa: E501
            return data

    def delete_ota_package_using_delete_with_http_info(self, ota_package_id, **kwargs):  # noqa: E501
        """Delete OTA Package (deleteOtaPackage)  # noqa: E501

        Deletes the OTA Package. Referencing non-existing OTA Package Id will cause an error. Can't delete the OTA Package if it is referenced by existing devices or device profile.  Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_ota_package_using_delete_with_http_info(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ota_package_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_ota_package_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ota_package_id' is set
        if ('ota_package_id' not in params or
                params['ota_package_id'] is None):
            raise ValueError("Missing the required parameter `ota_package_id` when calling `delete_ota_package_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'ota_package_id' in params:
            path_params['otaPackageId'] = params['ota_package_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/otaPackage/{otaPackageId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_ota_package_using_get(self, ota_package_id, **kwargs):  # noqa: E501
        """Download OTA Package (downloadOtaPackage)  # noqa: E501

        Download OTA Package based on the provided OTA Package Id.  Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_ota_package_using_get(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: Resource
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_ota_package_using_get_with_http_info(ota_package_id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_ota_package_using_get_with_http_info(ota_package_id, **kwargs)  # noqa: E501
            return data

    def download_ota_package_using_get_with_http_info(self, ota_package_id, **kwargs):  # noqa: E501
        """Download OTA Package (downloadOtaPackage)  # noqa: E501

        Download OTA Package based on the provided OTA Package Id.  Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_ota_package_using_get_with_http_info(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: Resource
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ota_package_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_ota_package_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ota_package_id' is set
        if ('ota_package_id' not in params or
                params['ota_package_id'] is None):
            raise ValueError("Missing the required parameter `ota_package_id` when calling `download_ota_package_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'ota_package_id' in params:
            path_params['otaPackageId'] = params['ota_package_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/otaPackage/{otaPackageId}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Resource',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ota_package_by_id_using_get(self, ota_package_id, **kwargs):  # noqa: E501
        """Get OTA Package (getOtaPackageById)  # noqa: E501

        Fetch the OTA Package object based on the provided OTA Package Id. The server checks that the OTA Package is owned by the same tenant. OTA Package is a heavyweight object that includes main information about the OTA Package and also data.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ota_package_by_id_using_get(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: OtaPackage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ota_package_by_id_using_get_with_http_info(ota_package_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ota_package_by_id_using_get_with_http_info(ota_package_id, **kwargs)  # noqa: E501
            return data

    def get_ota_package_by_id_using_get_with_http_info(self, ota_package_id, **kwargs):  # noqa: E501
        """Get OTA Package (getOtaPackageById)  # noqa: E501

        Fetch the OTA Package object based on the provided OTA Package Id. The server checks that the OTA Package is owned by the same tenant. OTA Package is a heavyweight object that includes main information about the OTA Package and also data.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ota_package_by_id_using_get_with_http_info(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: OtaPackage
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ota_package_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ota_package_by_id_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ota_package_id' is set
        if ('ota_package_id' not in params or
                params['ota_package_id'] is None):
            raise ValueError("Missing the required parameter `ota_package_id` when calling `get_ota_package_by_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'ota_package_id' in params:
            path_params['otaPackageId'] = params['ota_package_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/otaPackage/{otaPackageId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OtaPackage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ota_package_info_by_id_using_get(self, ota_package_id, **kwargs):  # noqa: E501
        """Get OTA Package Info (getOtaPackageInfoById)  # noqa: E501

        Fetch the OTA Package Info object based on the provided OTA Package Id. OTA Package Info is a lightweight object that includes main information about the OTA Package excluding the heavyweight data.   Available for users with 'TENANT_ADMIN' or 'CUSTOMER_USER' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ota_package_info_by_id_using_get(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: OtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ota_package_info_by_id_using_get_with_http_info(ota_package_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ota_package_info_by_id_using_get_with_http_info(ota_package_id, **kwargs)  # noqa: E501
            return data

    def get_ota_package_info_by_id_using_get_with_http_info(self, ota_package_id, **kwargs):  # noqa: E501
        """Get OTA Package Info (getOtaPackageInfoById)  # noqa: E501

        Fetch the OTA Package Info object based on the provided OTA Package Id. OTA Package Info is a lightweight object that includes main information about the OTA Package excluding the heavyweight data.   Available for users with 'TENANT_ADMIN' or 'CUSTOMER_USER' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ota_package_info_by_id_using_get_with_http_info(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :return: OtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ota_package_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ota_package_info_by_id_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ota_package_id' is set
        if ('ota_package_id' not in params or
                params['ota_package_id'] is None):
            raise ValueError("Missing the required parameter `ota_package_id` when calling `get_ota_package_info_by_id_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'ota_package_id' in params:
            path_params['otaPackageId'] = params['ota_package_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/otaPackage/info/{otaPackageId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OtaPackageInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ota_packages_using_get(self, page_size, page, **kwargs):  # noqa: E501
        """Get OTA Package Infos (getOtaPackages)  # noqa: E501

        Returns a page of OTA Package Info objects owned by tenant. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details. OTA Package Info is a lightweight object that includes main information about the OTA Package excluding the heavyweight data.   Available for users with 'TENANT_ADMIN' or 'CUSTOMER_USER' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ota_packages_using_get(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on the ota package title.
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataOtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ota_packages_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ota_packages_using_get_with_http_info(page_size, page, **kwargs)  # noqa: E501
            return data

    def get_ota_packages_using_get_with_http_info(self, page_size, page, **kwargs):  # noqa: E501
        """Get OTA Package Infos (getOtaPackages)  # noqa: E501

        Returns a page of OTA Package Info objects owned by tenant. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details. OTA Package Info is a lightweight object that includes main information about the OTA Package excluding the heavyweight data.   Available for users with 'TENANT_ADMIN' or 'CUSTOMER_USER' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ota_packages_using_get_with_http_info(page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on the ota package title.
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataOtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page', 'text_search', 'sort_property', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ota_packages_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_ota_packages_using_get`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_ota_packages_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/otaPackages{?page,pageSize,sortOrder,sortProperty,textSearch}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataOtaPackageInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_ota_packages_using_get1(self, device_profile_id, type, page_size, page, **kwargs):  # noqa: E501
        """Get OTA Package Infos (getOtaPackages)  # noqa: E501

        Returns a page of OTA Package Info objects owned by tenant. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details. OTA Package Info is a lightweight object that includes main information about the OTA Package excluding the heavyweight data.   Available for users with 'TENANT_ADMIN' or 'CUSTOMER_USER' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ota_packages_using_get1(device_profile_id, type, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_profile_id: A string value representing the device profile id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param str type: OTA Package type. (required)
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on the ota package title.
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataOtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_ota_packages_using_get1_with_http_info(device_profile_id, type, page_size, page, **kwargs)  # noqa: E501
        else:
            (data) = self.get_ota_packages_using_get1_with_http_info(device_profile_id, type, page_size, page, **kwargs)  # noqa: E501
            return data

    def get_ota_packages_using_get1_with_http_info(self, device_profile_id, type, page_size, page, **kwargs):  # noqa: E501
        """Get OTA Package Infos (getOtaPackages)  # noqa: E501

        Returns a page of OTA Package Info objects owned by tenant. You can specify parameters to filter the results. The result is wrapped with PageData object that allows you to iterate over result set using pagination. See the 'Model' tab of the Response Class for more details. OTA Package Info is a lightweight object that includes main information about the OTA Package excluding the heavyweight data.   Available for users with 'TENANT_ADMIN' or 'CUSTOMER_USER' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_ota_packages_using_get1_with_http_info(device_profile_id, type, page_size, page, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_profile_id: A string value representing the device profile id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param str type: OTA Package type. (required)
        :param int page_size: Maximum amount of entities in a one page (required)
        :param int page: Sequence number of page starting from 0 (required)
        :param str text_search: The case insensitive 'substring' filter based on the ota package title.
        :param str sort_property: Property of entity to sort by
        :param str sort_order: Sort order. ASC (ASCENDING) or DESC (DESCENDING)
        :return: PageDataOtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['device_profile_id', 'type', 'page_size', 'page', 'text_search', 'sort_property', 'sort_order']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_ota_packages_using_get1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'device_profile_id' is set
        if ('device_profile_id' not in params or
                params['device_profile_id'] is None):
            raise ValueError("Missing the required parameter `device_profile_id` when calling `get_ota_packages_using_get1`")  # noqa: E501
        # verify the required parameter 'type' is set
        if ('type' not in params or
                params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `get_ota_packages_using_get1`")  # noqa: E501
        # verify the required parameter 'page_size' is set
        if ('page_size' not in params or
                params['page_size'] is None):
            raise ValueError("Missing the required parameter `page_size` when calling `get_ota_packages_using_get1`")  # noqa: E501
        # verify the required parameter 'page' is set
        if ('page' not in params or
                params['page'] is None):
            raise ValueError("Missing the required parameter `page` when calling `get_ota_packages_using_get1`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'device_profile_id' in params:
            path_params['deviceProfileId'] = params['device_profile_id']  # noqa: E501
        if 'type' in params:
            path_params['type'] = params['type']  # noqa: E501

        query_params = []
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'text_search' in params:
            query_params.append(('textSearch', params['text_search']))  # noqa: E501
        if 'sort_property' in params:
            query_params.append(('sortProperty', params['sort_property']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('sortOrder', params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/otaPackages/{deviceProfileId}/{type}{?page,pageSize,sortOrder,sortProperty,textSearch}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageDataOtaPackageInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_ota_package_data_using_post(self, ota_package_id, **kwargs):  # noqa: E501
        """Save OTA Package data (saveOtaPackageData)  # noqa: E501

        Update the OTA Package. Adds the date to the existing OTA Package Info  Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_ota_package_data_using_post(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param str checksum:
        :param str checksum_algorithm:
        :param str file:
        :return: OtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_ota_package_data_using_post_with_http_info(ota_package_id, **kwargs)  # noqa: E501
        else:
            (data) = self.save_ota_package_data_using_post_with_http_info(ota_package_id, **kwargs)  # noqa: E501
            return data

    def save_ota_package_data_using_post_with_http_info(self, ota_package_id, **kwargs):  # noqa: E501
        """Save OTA Package data (saveOtaPackageData)  # noqa: E501

        Update the OTA Package. Adds the date to the existing OTA Package Info  Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_ota_package_data_using_post_with_http_info(ota_package_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ota_package_id: A string value representing the ota package id. For example, '784f394c-42b6-435a-983c-b7beff2784f9' (required)
        :param str checksum:
        :param str checksum_algorithm:
        :param str file:
        :return: OtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ota_package_id', 'checksum', 'checksum_algorithm', 'file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_ota_package_data_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ota_package_id' is set
        if ('ota_package_id' not in params or
                params['ota_package_id'] is None):
            raise ValueError("Missing the required parameter `ota_package_id` when calling `save_ota_package_data_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'ota_package_id' in params:
            path_params['otaPackageId'] = params['ota_package_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'checksum' in params:
            form_params.append(('checksum', params['checksum']))  # noqa: E501
        if 'checksum_algorithm' in params:
            form_params.append(('checksumAlgorithm', params['checksum_algorithm']))  # noqa: E501
        if 'file' in params:
            local_var_files['file'] = params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/otaPackage/{otaPackageId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OtaPackageInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def save_ota_package_info_using_post(self, **kwargs):  # noqa: E501
        """Create Or Update OTA Package Info (saveOtaPackageInfo)  # noqa: E501

        Create or update the OTA Package Info. When creating OTA Package Info, platform generates OTA Package id as [time-based UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Version_1_(date-time_and_MAC_address)). The newly created OTA Package id will be present in the response. Specify existing OTA Package id to update the OTA Package Info. Referencing non-existing OTA Package Id will cause 'Not Found' error.   OTA Package combination of the title with the version is unique in the scope of tenant.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_ota_package_info_using_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SaveOtaPackageInfoRequest body:
        :return: OtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.save_ota_package_info_using_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.save_ota_package_info_using_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def save_ota_package_info_using_post_with_http_info(self, **kwargs):  # noqa: E501
        """Create Or Update OTA Package Info (saveOtaPackageInfo)  # noqa: E501

        Create or update the OTA Package Info. When creating OTA Package Info, platform generates OTA Package id as [time-based UUID](https://en.wikipedia.org/wiki/Universally_unique_identifier#Version_1_(date-time_and_MAC_address)). The newly created OTA Package id will be present in the response. Specify existing OTA Package id to update the OTA Package Info. Referencing non-existing OTA Package Id will cause 'Not Found' error.   OTA Package combination of the title with the version is unique in the scope of tenant.   Available for users with 'TENANT_ADMIN' authority.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.save_ota_package_info_using_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SaveOtaPackageInfoRequest body:
        :return: OtaPackageInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method save_ota_package_info_using_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['X-Authorization']  # noqa: E501

        return self.api_client.call_api(
            '/api/otaPackage', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='OtaPackageInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

from .o_auth_2_config_template_controller_api import OAuth2ConfigTemplateControllerApi
from .asset_controller_api import AssetControllerApi
from .rule_chain_controller_api import RuleChainControllerApi
from .auth_controller_api import AuthControllerApi
from .event_controller_api import EventControllerApi
from .telemetry_controller_api import TelemetryControllerApi
from .alarm_controller_api import AlarmControllerApi
from .edge_controller_api import EdgeControllerApi
from .rpc_v_2_controller_api import RpcV2ControllerApi
from .edge_event_controller_api import EdgeEventControllerApi
from .customer_controller_api import CustomerControllerApi
from .user_controller_api import UserControllerApi
from .queue_controller_api import QueueControllerApi
from .rpc_v_1_controller_api import RpcV1ControllerApi
from .device_controller_api import DeviceControllerApi
from .entity_relation_controller_api import EntityRelationControllerApi
from .entity_view_controller_api import EntityViewControllerApi
from .admin_controller_api import AdminControllerApi
from .tb_resource_controller_api import TbResourceControllerApi
from .o_auth_2_controller_api import OAuth2ControllerApi
from .tenant_profile_controller_api import TenantProfileControllerApi
from .widgets_bundle_controller_api import WidgetsBundleControllerApi
from .device_profile_controller_api import DeviceProfileControllerApi
from .dashboard_controller_api import DashboardControllerApi
from .entity_query_controller_api import EntityQueryControllerApi
from .widget_type_controller_api import WidgetTypeControllerApi
from .audit_log_controller_api import AuditLogControllerApi
from .lwm_2m_controller_api import Lwm2mControllerApi
from .component_descriptor_controller_api import ComponentDescriptorControllerApi
from .tenant_controller_api import TenantControllerApi
from .ota_package_controller_api import OtaPackageControllerApi
from .entities_version_control_controller_api import EntitiesVersionControlControllerApi
from .device_api_controller_api import DeviceApiControllerApi
from .two_factor_auth_controller_api import TwoFactorAuthControllerApi
from .alarm_comment_controller_api import AlarmCommentControllerApi
from .asset_profile_controller_api import AssetProfileControllerApi
from .notification_controller_api import NotificationControllerApi
from .notification_rule_controller_api import NotificationRuleControllerApi
from .notification_target_controller_api import NotificationTargetControllerApi
from .notification_template_controller_api import NotificationTemplateControllerApi
from .usage_info_controller_api import UsageInfoControllerApi
from .two_factor_auth_config_controller_api import TwoFactorAuthConfigControllerApi
from .image_controller_api import ImageControllerApi



# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.6.2PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class SolutionInstallResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dashboard_group_id': 'EntityGroupId',
        'dashboard_id': 'DashboardId',
        'public_id': 'CustomerId',
        'main_dashboard_public': 'bool',
        'success': 'bool',
        'details': 'str'
    }

    attribute_map = {
        'dashboard_group_id': 'dashboardGroupId',
        'dashboard_id': 'dashboardId',
        'public_id': 'publicId',
        'main_dashboard_public': 'mainDashboardPublic',
        'success': 'success',
        'details': 'details'
    }

    def __init__(self, dashboard_group_id=None, dashboard_id=None, public_id=None, main_dashboard_public=None, success=None, details=None):  # noqa: E501
        """SolutionInstallResponse - a model defined in Swagger"""  # noqa: E501
        self._dashboard_group_id = None
        self._dashboard_id = None
        self._public_id = None
        self._main_dashboard_public = None
        self._success = None
        self._details = None
        self.discriminator = None
        if dashboard_group_id is not None:
            self.dashboard_group_id = dashboard_group_id
        if dashboard_id is not None:
            self.dashboard_id = dashboard_id
        if public_id is not None:
            self.public_id = public_id
        if main_dashboard_public is not None:
            self.main_dashboard_public = main_dashboard_public
        if success is not None:
            self.success = success
        if details is not None:
            self.details = details

    @property
    def dashboard_group_id(self):
        """Gets the dashboard_group_id of this SolutionInstallResponse.  # noqa: E501


        :return: The dashboard_group_id of this SolutionInstallResponse.  # noqa: E501
        :rtype: EntityGroupId
        """
        return self._dashboard_group_id

    @dashboard_group_id.setter
    def dashboard_group_id(self, dashboard_group_id):
        """Sets the dashboard_group_id of this SolutionInstallResponse.


        :param dashboard_group_id: The dashboard_group_id of this SolutionInstallResponse.  # noqa: E501
        :type: EntityGroupId
        """

        self._dashboard_group_id = dashboard_group_id

    @property
    def dashboard_id(self):
        """Gets the dashboard_id of this SolutionInstallResponse.  # noqa: E501


        :return: The dashboard_id of this SolutionInstallResponse.  # noqa: E501
        :rtype: DashboardId
        """
        return self._dashboard_id

    @dashboard_id.setter
    def dashboard_id(self, dashboard_id):
        """Sets the dashboard_id of this SolutionInstallResponse.


        :param dashboard_id: The dashboard_id of this SolutionInstallResponse.  # noqa: E501
        :type: DashboardId
        """

        self._dashboard_id = dashboard_id

    @property
    def public_id(self):
        """Gets the public_id of this SolutionInstallResponse.  # noqa: E501


        :return: The public_id of this SolutionInstallResponse.  # noqa: E501
        :rtype: CustomerId
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this SolutionInstallResponse.


        :param public_id: The public_id of this SolutionInstallResponse.  # noqa: E501
        :type: CustomerId
        """

        self._public_id = public_id

    @property
    def main_dashboard_public(self):
        """Gets the main_dashboard_public of this SolutionInstallResponse.  # noqa: E501

        Is the main dashboard public  # noqa: E501

        :return: The main_dashboard_public of this SolutionInstallResponse.  # noqa: E501
        :rtype: bool
        """
        return self._main_dashboard_public

    @main_dashboard_public.setter
    def main_dashboard_public(self, main_dashboard_public):
        """Sets the main_dashboard_public of this SolutionInstallResponse.

        Is the main dashboard public  # noqa: E501

        :param main_dashboard_public: The main_dashboard_public of this SolutionInstallResponse.  # noqa: E501
        :type: bool
        """

        self._main_dashboard_public = main_dashboard_public

    @property
    def success(self):
        """Gets the success of this SolutionInstallResponse.  # noqa: E501

        Indicates that template was installed successfully  # noqa: E501

        :return: The success of this SolutionInstallResponse.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this SolutionInstallResponse.

        Indicates that template was installed successfully  # noqa: E501

        :param success: The success of this SolutionInstallResponse.  # noqa: E501
        :type: bool
        """

        self._success = success

    @property
    def details(self):
        """Gets the details of this SolutionInstallResponse.  # noqa: E501

        Markdown with solution usage instructions  # noqa: E501

        :return: The details of this SolutionInstallResponse.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this SolutionInstallResponse.

        Markdown with solution usage instructions  # noqa: E501

        :param details: The details of this SolutionInstallResponse.  # noqa: E501
        :type: str
        """

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SolutionInstallResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SolutionInstallResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
